@@ -25,6 +25,7 @@
 #include <ctype.h>
 
 #include <panel-applet-gconf.h>
+#include <egg-screen-help.h>
 #include "geyes.h"
 
 gchar *theme_directories[] = {
@@ -84,9 +85,7 @@ load_theme (EyesApplet *eyes_applet, const gchar *theme_dir)
 
         eyes_applet->theme_dir = g_strdup_printf ("%s/", theme_dir);
 
-        file_name = g_malloc (strlen (theme_dir) + strlen ("/config") + 1);
-        strcpy (file_name, theme_dir);
-        strcat (file_name, "/config");
+        file_name = g_strdup_printf("%s%s",theme_dir,"/config");
         theme_file = fopen (file_name, "r");
         if (theme_file == NULL) {
                 g_error ("Unable to open theme file.");
@@ -164,20 +163,32 @@ theme_selected_cb (GtkTreeSelection *selection, gpointer data)
 	g_free (theme);
 }
 
-#ifdef FIXME
 static void
-phelp_cb (GtkWidget *w, gint tab, gpointer data)
+phelp_cb (GtkDialog *dialog)
 {
-	GnomeHelpMenuEntry help_entry = { "geyes_applet",
-					  "index.html#GEYES-PREFS" };
-	gnome_help_display(NULL, &help_entry);
+	GError *error = NULL;
+
+	egg_help_display_on_screen (
+		"geyes", "geyes-settings",
+		gtk_window_get_screen (GTK_WINDOW (dialog)),
+		&error);
+
+	if (error) { /* FIXME: the user needs to see this */
+		g_warning ("help error: %s\n", error->message);
+		g_error_free (error);
+		error = NULL;
+	}
 }
-#endif
 
 static void
 presponse_cb (GtkDialog *dialog, gint id, gpointer data)
 {
 	EyesApplet *eyes_applet = data;
+	if(id == GTK_RESPONSE_HELP){
+		phelp_cb (dialog);
+		return;
+	}
+
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
 
@@ -185,7 +196,9 @@ presponse_cb (GtkDialog *dialog, gint id, gpointer data)
 }
 
 void
-properties_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
+properties_cb (BonoboUIComponent *uic,
+	       EyesApplet        *eyes_applet,
+	       const gchar       *verbname)
 {
 	GtkWidget *pbox, *hbox;
         GtkWidget *tree;
@@ -199,18 +212,23 @@ properties_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname
         struct dirent *dp;
         int i;
         gchar filename [PATH_MAX];
-	EyesApplet *eyes_applet = user_data;
      
 	if (eyes_applet->prop_box.pbox) {
-		gdk_window_show (eyes_applet->prop_box.pbox->window);
-		gdk_window_raise (eyes_applet->prop_box.pbox->window);
+		gtk_window_set_screen (
+			GTK_WINDOW (eyes_applet->prop_box.pbox),
+			gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)));
+		gtk_window_present (GTK_WINDOW (eyes_applet->prop_box.pbox));
 		return;
 	}
 
         pbox = gtk_dialog_new_with_buttons (_("Geyes Preferences"), NULL,
         				     GTK_DIALOG_DESTROY_WITH_PARENT,
 					     GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+					     GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 					     NULL);
+	gtk_window_set_screen (GTK_WINDOW (pbox),
+			       gtk_widget_get_screen (GTK_WIDGET (eyes_applet->applet)));
+        gtk_dialog_set_default_response(GTK_DIALOG (pbox), GTK_RESPONSE_CLOSE);
 
         g_signal_connect (pbox, "response",
 			  G_CALLBACK (presponse_cb),
@@ -219,7 +237,7 @@ properties_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname
 	hbox = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (pbox)->vbox), hbox, FALSE, FALSE, 2);
 	
-	label = gtk_label_new_with_mnemonic (_("T_heme Name"));
+	label = gtk_label_new_with_mnemonic (_("_Theme Name:"));
 	gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
