@@ -94,8 +94,8 @@ gkb_draw (GKB * gkb)
       g_return_if_fail (gkb->keymap != NULL);
       g_return_if_fail (gkb->keymap->pixbuf != NULL);
       
-      tmp = gdk_pixbuf_scale_simple (gkb->keymap->pixbuf, gkb->w, 
-      				     gkb->h, GDK_INTERP_HYPER); 
+      tmp = gdk_pixbuf_scale_simple (gkb->keymap->pixbuf, gkb->w * 0.9, 
+      				     gkb->h * 0.9, GDK_INTERP_HYPER); 
       if (tmp) {     
         gtk_image_set_from_pixbuf (GTK_IMAGE (gkb->image), tmp);
         g_object_unref (tmp);
@@ -206,9 +206,9 @@ gkb_count_sizes (GKB * gkb)
 	applet_width += label_width;
     }
 
-  gkb->w = flag_width;
-  /* FIXME the applet is just a little bigger than panel, so I add the -1 here*/
-  gkb->h = flag_height - 1; 
+  gkb->w = flag_width - 1;
+  /* FIXME the applet is just a little bigger than panel, so I add the -2 here*/
+  gkb->h = flag_height - 1;
   gtk_widget_set_size_request (gkb->label_frame1, gkb->w, gkb->h);
   gtk_widget_set_size_request (gkb->label_frame2, gkb->w, gkb->h);
   gtk_widget_set_size_request (gkb->darea_frame, gkb->w, gkb->h);
@@ -287,6 +287,31 @@ gkb_sized_render (GKB * gkb)
 
 }
 
+void gkb_update_handlers (GKB *gkb, gboolean disconnect)
+{
+  GdkWindow *root_window;
+
+  root_window = gdk_get_default_root_window ();
+
+  if (disconnect)
+  {
+    if (gkb->button_press_id != -1)
+      g_signal_handler_disconnect (gkb->eventbox, gkb->button_press_id);
+    gkb->button_press_id = -1;
+
+    gdk_window_remove_filter (root_window, event_filter, gkb);
+  }
+  else {
+    gdk_window_add_filter (root_window, event_filter, gkb);
+
+    if (gkb->button_press_id == -1)
+      gkb->button_press_id = g_signal_connect (gkb->eventbox, "button_press_event",
+                                               G_CALLBACK (gkb_button_press_event_cb), gkb);
+
+  }
+
+}
+
 /**
  * gkb_update:
  * @gkb: the GKB. global, so redundant
@@ -303,8 +328,10 @@ gkb_update (GKB * gkb, gboolean set_command)
    * keymap, so when the set_commadn is false, it means that we
    * have changed size. In other words, we can't change size &
    * keymap at the same time */
-  if (set_command)
+  if (set_command) {
+    gkb_update_handlers (gkb, TRUE);
     gkb_system_set_keymap (gkb);
+  }
   else
     gkb_sized_render (gkb);
 
@@ -466,9 +493,12 @@ load_properties (GKB * gkb)
 
   gkb->n = gconf_applet_get_int (PANEL_APPLET(gkb->applet), "num", NULL);
 
-  gkb->key = gkb_load_pref (gkb, "key", "Mod1-Shift_L");
+  gkb->key = gkb_load_pref (gkb, "key", "Alt-Shift_L");
+  gkb->old_key = g_strdup (gkb->key);
 
   convert_string_to_keysym_state (gkb->key, &gkb->keysym, &gkb->state);
+  gkb->old_keysym = gkb->keysym;
+  gkb->old_state = gkb->state;
 
   gkb->is_small = gconf_applet_get_bool (PANEL_APPLET(gkb->applet), "small", NULL);
 #ifdef THIS_IS_UNNECESSARY
@@ -536,11 +566,11 @@ create_gkb_widget (GKB *gkb)
 
   gkb->image = gtk_image_new ();
 
-  g_signal_connect (gkb->eventbox, "button_press_event",
-                    G_CALLBACK (gkb_button_press_event_cb), gkb);
+  gkb->button_press_id = g_signal_connect (gkb->eventbox, "button_press_event",
+                                           G_CALLBACK (gkb_button_press_event_cb), gkb);
 
   gkb->darea_frame = gtk_frame_new (NULL);
-  gtk_frame_set_shadow_type (GTK_FRAME (gkb->darea_frame), GTK_SHADOW_IN);
+  gtk_frame_set_shadow_type (GTK_FRAME (gkb->darea_frame), GTK_SHADOW_OUT);
   gtk_container_add (GTK_CONTAINER (gkb->darea_frame), gkb->image);
   gtk_box_pack_start (GTK_BOX (gkb->vbox), gkb->darea_frame, TRUE, TRUE, 0);
 #if 0
@@ -647,9 +677,10 @@ help_cb (BonoboUIComponent *uic,
 {
 	GError *error = NULL;
 
-	egg_screen_help_display (
+	egg_help_display_on_screen (
+			"gkb", NULL,
 			gtk_widget_get_screen (gkb->applet),
-			"gkb", NULL, &error);
+			&error);
 
 	/* FIXME: display error to the user */
 }
@@ -657,7 +688,10 @@ help_cb (BonoboUIComponent *uic,
 static GdkFilterReturn
 global_key_filter (GKB *gkb, GdkXEvent * gdk_xevent, GdkEvent * event)
 {
-  if (event->key.keyval == gkb->keysym && event->key.state == gkb->state)
+  XKeyEvent * xkevent = (XKeyEvent *) gdk_xevent;
+  gint keysym = XKeycodeToKeysym(GDK_DISPLAY(), xkevent->keycode,0);
+
+ if (strcmp (gkb->key, convert_keysym_state_to_string (XKeycodeToKeysym(GDK_DISPLAY (), xkevent->keycode, 0), xkevent->state)) == 0)
     {
       if (gkb->cur + 1 < gkb->n)
 	gkb->keymap = g_list_nth_data (gkb->maps, ++gkb->cur);
@@ -682,7 +716,7 @@ event_filter (GdkXEvent * gdk_xevent, GdkEvent * event, gpointer data)
 
   xevent = (XEvent *) gdk_xevent;
 
-  if (xevent->type == KeyRelease)
+  if (xevent->type == KeyPress)
     {
       return global_key_filter (gkb, gdk_xevent, event);
     }
@@ -766,15 +800,9 @@ static const BonoboUIVerb gkb_menu_verbs [] = {
 	BONOBO_UI_VERB_END
 };
 
-static void gkb_destroy (GtkWidget * widget, gpointer data) {
-	gchar *cmd;
+static void gkb_destroy (GtkWidget * widget, gpointer data)
+{
 	GKB *gkb = (GKB *)data;
-
-	/* restore the default keymap before exiting */
-	cmd = g_strdup_printf ("xmodmap %s/.gkb_default.xmm", g_get_home_dir ());
-	system (cmd);
-	g_free (cmd);
-
 	g_free(gkb);
 }
 
@@ -805,13 +833,19 @@ gboolean fill_gkb_applet(PanelApplet *applet)
   gtk_widget_show (gkb->darea_frame);
   gtk_container_add (GTK_CONTAINER (gkb->applet), gkb->eventbox);
 
+
   keycode = XKeysymToKeycode(GDK_DISPLAY(), gkb->keysym);
 
   modifiers = gkb->state;
 
   root_window = gdk_get_default_root_window ();
 
+  gkb->keycode = keycode; 
+  /* Incase the key is already grabbed by another application */ 
+  gdk_error_trap_push ();
   gkb_xgrab (keycode, modifiers, root_window);
+  gdk_flush ();
+  gdk_error_trap_pop ();
   gdk_window_add_filter (root_window, event_filter, gkb);
 
   g_signal_connect (G_OBJECT(gkb->applet),
